@@ -1,6 +1,7 @@
 //! Interpreter module.
 //!
 use super::parser::Parser;
+use super::lexer::Lexer;
 
 #[derive(Debug)]
 /// Interpreter struct
@@ -8,7 +9,8 @@ pub struct Interpreter {
     file_name: String,
     content: String,
     imports: Vec<Box<Interpreter>>,
-    parser: Parser,
+    parser: Option<Parser>,
+    lexer: Lexer,
 }
 
 impl Interpreter {
@@ -18,13 +20,17 @@ impl Interpreter {
             file_name: arg_file_name.clone(),
             content: arg_content.clone(),
             imports: vec![],
-            parser: Parser::new(arg_file_name, arg_content),
+            parser: None,
+            lexer: Lexer::new(arg_content),
         }
     }
     /// File name accessor.
     pub fn get_name(&self) -> String { return self.file_name.clone();}
     /// Interpreter execution function
-    pub fn run(&mut self) {
-       self.parser.parse();
+    pub fn run(&mut self) -> i32 {
+        if let Err(mut e) = self.lexer.lex() {
+            e.module_name = self.file_name.clone();
+            1
+        } else {0}
     }
 }
\ No newline at end of file
