@@ -5,19 +5,14 @@ use super::interpreter;
 
 struct IOError {
     info: String,
-    error_type: String,
-    level: String,
 }
 
 impl IOError {
-    fn new(i: String, l: String) -> IOError {
-        IOError{ info: i, error_type: "IOError".to_string(), level: l}
+    fn new(i: String) -> IOError {
+        IOError{info: i}
     }
     fn panic(&self) -> i32 {
-        println!("
-{}:{}:
-    {}
-        ", self.level, self.error_type, self.info);
+        println!("\nArgumentError:\n\t{}", self.info);
         return 1;
     }
 }
@@ -25,7 +20,8 @@ impl IOError {
 /// Interprets the Wright file at the file name passed into the argument.
 /// Returns the operating system exit code (Generally 0 for a success, 1 for a failure.).
 pub fn interpret_file(input_file: String) -> i32 { // the i32 is exit code
-    let file_error = IOError::new("Could not open or read input file.".to_string(), "Fatal".to_string());
+    let file_error = IOError::new("Could not read input file.".to_string());
+    // set input file if it can be opened
     let mut input_f = if let Ok(n) = File::open(input_file.clone()) {
         n
     } else {
@@ -36,7 +32,6 @@ pub fn interpret_file(input_file: String) -> i32 { // the i32 is exit code
         return file_error.panic();
     };
     let mut call: interpreter::Interpreter = interpreter::Interpreter::new(input_file, input_file_contents);
-    call.run();
-    return 0;
+    return call.run();
     // assume success.
 }
\ No newline at end of file
